@@ -809,8 +809,40 @@ def compute_plot_excel_kpis_meterics_metrics(data, title, local_root_directory='
                 epochkpis_df.to_excel(writer, sheet_name='kpis per epoch')
                 writer.save()
             if plot_html:
+                to_plot_df = epochkpis_df.copy()
+                from datetime import datetime
+                def compute_date(row):
+                    year = int(row['year'])
+                    month = None
+                    if row['month'] == 'January':
+                        month=1
+                    if row['month'] == 'February':
+                        month=2
+                    if row['month'] == 'March':
+                        month=3
+                    if row['month'] == 'April':
+                        month=4
+                    if row['month'] == 'May':
+                        month=5
+                    if row['month'] == 'June':
+                        month=6
+                    if row['month'] == 'July':
+                        month=7
+                    if row['month'] == 'August':
+                        month=8
+                    if row['month'] == 'September':
+                        month=9
+                    if row['month'] ==  'October':
+                        month=10
+                    if row['month'] == 'November':
+                        month=11
+                    if row['month'] == 'December':
+                        month=12
+                    return datetime(year=year, month=month, day=1)
 
-                to_plot_df = epochkpis_df[
+                to_plot_df['date']=to_plot_df.apply(compute_date,axis=1)
+                to_plot_df = to_plot_df.set_index('date')
+                to_plot_df = to_plot_df[
                     ['epoch realized return', 'epoch realized max drawdown']].copy()
                 fig = realtime_plotting_utility.plot_multiple_bar_series(
                     data_df=to_plot_df[['epoch realized return']] * 100.,
